@@ -51,14 +51,15 @@ sub run {
     my $call = $self->can("cmd_$cmd")
       or die "Can't find command '$cmd': run `carmel help` to see the list of commands.\n";
 
+    my $code = 0;
     try {
         $self->$call(@args);
     } catch {
         warn $_;
-        return 255;
+        $code = 1;
     };
 
-    return 0;
+    return $code;
 }
 
 sub repository_base {
@@ -97,25 +98,25 @@ sub cmd_inject {
 sub cmd_update {
     my($self, @args) = @_;
 
-    my $current = $self->snapshot
+    my $snapshot = $self->snapshot
       or die "Can't run carmel update without snapshot. Run `carmel install` first.\n";
 
     for my $module (@args) {
-        my $dist = $current->find($module)
+        my $dist = $snapshot->find($module)
           or die "$module is not found in the snapshot.\n";
     }
 
-    # create a new snapshot and copy needed dists over, since Carton::Snapshot is immutable for now
-    my $snapshot = Carton::Snapshot->new(path => $current->path);
-
     if (@args) {
-        my @dists = grep !$self->dist_provides_any($_, \@args), $current->distributions;
-        for my $dist (@dists) {
-            $snapshot->add_distribution($dist);
+        for my $module (@args) {
+            $snapshot->remove_distributions(sub {
+                my $dist = shift;
+                $dist->provides_module($module);
+            });
         }
         $self->install_with_snapshot($snapshot, [], @args);
     } else {
         # remove everything from the snapshot
+        $snapshot->remove_distributions(sub { 1 });
         my $cpanfile = $self->try_cpanfile
           or die "Can't locate 'cpanfile' to load module list.\n";
         $self->install_with_cpanfile(Module::CPANfile->load($cpanfile), $snapshot);
@@ -130,9 +131,8 @@ sub cmd_update {
 sub dist_provides_any {
     my($self, $dist, $modules) = @_;
 
-    my $provides = $dist->provides or return;
     for my $mod (@$modules) {
-        return 1 if $provides->{$mod};
+        return 1 if $dist->provides_module($mod);
     }
 
     return;
@@ -407,7 +407,7 @@ sub artifact_for {
     eval {
         $self->resolve(sub {
             my $artifact = shift;
-            if ($module eq $artifact->package) {
+            if (exists $artifact->provides->{$module}) {
                 $found = $artifact;
                 die "__FOUND__\n";
             }
@@ -543,29 +543,6 @@ sub build_index {
     $index;
 }
 
-sub cmd_binstubs {
-    my($self, @package) = @_;
-
-    die "Usage: carmel binstubs Module [...]\n" unless @package;
-
-    for my $package (@package) {
-        my $artifact = $self->artifact_for($package);
-        my %execs = $artifact->executables;
-        for my $bin (keys %execs) {
-            my $path = Path::Tiny->new("bin/$bin");
-            $path->parent->mkpath;
-            $path->spew(<<EOF);
-#!/usr/bin/env perl
-# This file was generated by Carmel
-use Carmel::Setup;
-my \$res = do Carmel::Setup->bin_path('@{[ $artifact->package ]}', '$bin');
-if (!defined \$res and my \$err = \$@ || \$!) { die \$err }
-EOF
-            $path->chmod(0755);
-        }
-    }
-}
-
 sub try_cpanfile {
     my $self = shift;
     $self->locate_cpanfile($ENV{PERL_CARMEL_CPANFILE});
